
# Type: genetically interacts with


holds between two genes whose phenotypic effects are dependent on each other in some way - such that their combined phenotypic effects are the result of some interaction between the activity of their gene products. Examples include epistasis and synthetic lethality.

URI: [biolink:genetically_interacts_with](https://w3id.org/biolink/vocab/genetically_interacts_with)


## Domain and Range

[Gene](Gene.md) ->  <sub>0..*</sub> [Gene](Gene.md)

## Parents

 *  is_a: [interacts with](interacts_with.md)

## Children


## Used by

 * [Gene](Gene.md)

## Other properties

|  |  |  |
| --- | --- | --- |
| **Mappings:** | | RO:0002435 |
| **In Subsets:** | | translator_minimal |

